{% extends 'dashboard/index.html' %}
    {% block content %}
    <div id="content">
        <section>
          <div class="container main-title">
            <div class="row">
              <div class="col-lg-9">
                <h1 class="font-weight-bold"><i class="fas fa-chart-line"></i> Analytics</h1>
                <P class="text-muted">Estadisticas generales</P>
              </div>
            </div>
          </div>
        </section>
    </div>
 </div> 
  </div>
  {% endblock content %}
</html>