{% extends 'accounts/base.html' %}
{% load static %}
{% block head_title %}| Un vinculo entre nosotros.{% endblock %}
{% block content %}
<div class="container mx-auto login-view vh-100">
    <div class="row justify-content-center">
        <div class="col-sm-12 col-lg-10 pt-4 main-logo">
            <img src="{% static 'img/oficial.png' %}">
        </div>
        <div class="col-sm-12 col-lg-10">
            <div class="instant-messages">
                {% if messages %}
                    {% for message in messages %}
                        <div class="alert alert-{{ message.tags }} alert-dismissible fade show" role="alert">
                            <span class="alert-inner--icon"><i class="ni ni-like-2"></i></span>
                            <span class="alert-inner--text">{{ message }}</span>
                            <button type="button" class="close" data-dismiss="alert" aria-label="close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                    {% endfor %}
                {% endif %}
            </div>
            <div class="center-message">
               <p>Su cuenta ha sido desactivada. Muchas gracias por preferirnos</p> 
            </div>
        </div>
    </div>
</div>
{% endblock  %}