# Generated by Django 4.2.1 on 2023-12-04 14:00

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stela_control', '0005_club_resource_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='facebookpageevent',
            name='lang',
            field=models.CharField(default='en', max_length=80),
        ),
        migrations.AddField(
            model_name='facebookpageevent',
            name='location',
            field=models.CharField(default='No location selected', max_length=250),
        ),
        migrations.AddField(
            model_name='facebookpageevent',
            name='owner',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='event_owner', to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge'), ('budget_design', 'Budget Design'), ('Others', 'Others'), ('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Education and Training', 'Education and Training'), ('IT Development Services', 'IT Development Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Media Creators', 'Media Creators'), ('E-commerce', 'E-commerce'), ('Consulting', 'Consulting'), ('Health and Wellness', 'Health and Wellness'), ('Restaurants and Food Services', 'Restaurants and Food Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue'), ('card-light-danger', 'card-light-danger')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Inspiration', 'Inspiration'), ('Guides and Manuals', 'Guides and Manuals'), ('Tips and Tricks', 'Tips and Tricks'), ('Events and Conferences', 'Events and Conferences'), ('Tutorials', 'Tutorials'), ('News', 'News'), ('Interviews', 'Interviews')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 4, 10, 59, 56, 624443)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Initial Payment', 'Initial Payment'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected'), ('Promotional Discount', 'Promotional Discount')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Elastic Instance', 'Cloud Elastic Instance')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 3', 'Step 3'), ('Step 4', 'Step 4')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('monthly_terms', 'Billing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('Disclaimer', 'Disclaimer'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('Return Policy', 'Return Policy'), ('budget_design_terms', 'Budget Design Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('Facebook', 'Facebook'), ('Youtube', 'Youtube'), ('Linkedin', 'Linkedin'), ('Github', 'Github'), ('X', 'X')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Payments Issue', 'Payments Issue'), ('I have a problem with my project', 'I have a problem with my project'), ('Others', 'Others')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Binance', 'Binance'), ('Zelle', 'Zelle'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]
