{% extends 'stela_control/home.html' %}
{% load i18n %}
{% load static %}
{% block meta %}
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="provide technological's tools for development's ecommerce and shop products">
    <meta name="keywords" content="Ecommerce, Consulting, Development, Shop, Branding, Marketing,">
    <meta name="author" content="Emmerut Group"/>
    <meta name="copyright" content="Emmerut Group LLC"/>
    <meta name="robots" content="index" />
{% endblock  %}
{% block head_title %}Emmerut | Stela Control Dynamic. {% trans "The Power is Yours" %}. {% endblock %}
{% block favicon %}
    <link rel="shortcut icon" href="https://emmerutcdn.s3.amazonaws.com/static/img/favicon.png" type="image/x-icon">
    <link rel="apple-touch-icon" href="https://emmerutcdn.s3.amazonaws.com/static/img/favicon.png" type="image/x-icon">
{% endblock  %}
{% block base_style %}
    <link rel="stylesheet" href="{% static 'css/stelaStyles.css' %}">
    <link rel="stylesheet" href="https://emmerutcdn.s3.amazonaws.com/static/vendor/css/core.css" class="template-customizer-core-css"/>     
{% endblock  %}
{% block styles %}
{% endblock %} 
{% block body %}
    {% block content %}
    {% endblock %}
    <script src="https://emmerutcdn.s3.amazonaws.com/static/js/site/preloader.js"></script> 
{% endblock %}
