{% load i18n %}
<div class="my-3">
  <p class="oxanium text-danger text-justify">{% trans "It is not possible to access the functions of a page if you have a connected Instagram Professional account. Please disconnect your current Instagram account before attempting any interaction with this page" %}.</p>
  <p class="oxanium text-danger text-justify">{% trans "If you need assistance or have any questions, please don't hesitate to contact our support team" %}.</p>
  <p class="oxanium text-danger text-justify">{% trans "Thank you for your understanding" %}.</p>
</div>




